@@ -14,7 +14,9 @@ from typedpy.structures import (
     ImmutableField,
     unique,
     Partial,
-    Extend
+    Omit,
+    Pick,
+    Extend,
 )
 from typedpy.fields import (
     Number,
