@@ -1,5 +1,6 @@
 import json
 import sys
+from functools import reduce
 
 
 def wrap_val(v):
@@ -27,6 +28,18 @@ def raise_errs_if_needed(errors):
         raise errors[0].__class__(messages) from errors[0]
 
 
+def deep_get(dictionary, deep_key):
+    keys = deep_key.split(".")
+    return reduce(lambda d, key: d.get(key) if d else None, keys, dictionary)
+
+
+def nested(func, default=None):
+    try:
+        return func()
+    except (AttributeError, IndexError):
+        return default
+
+
 py_version = sys.version_info[0:2]
 python_ver_36 = py_version == (3, 6)
 python_ver_atleast_than_37 = py_version > (3, 6)
